==> Text-MicroMason-1.91_0.tar.gz: Text-MicroMason-1.91/MicroMason/CatchErrors.pm <==
package Text::MicroMason::CatchErrors;

use strict;
use Carp;

######################################################################

use vars qw( %Defaults );

$Defaults{ error_string } = 1;

######################################################################

use vars qw( @MIXIN );

BEGIN { push @MIXIN, '#line '.__LINE__.' "'.__FILE__.'"', '', <<'/' }
sub compile {
  my $result = eval { local $SIG{__DIE__}; (shift)->SUPER::compile(@_) };
  wantarray ? ($result, $@) : $result;
}

sub execute {
  my $result = eval { local $SIG{__DIE__}; (shift)->SUPER::execute(@_) };
  wantarray ? ($result, $@) : $result;
}
/

######################################################################

1;

__END__

######################################################################

=head1 NAME

Text::MicroMason::CatchErrors - Catch template exceptions


=head1 SYNOPSIS

Instead of using this class directly, pass its name to be mixed in:

    use Text::MicroMason;
    my $mason = Text::MicroMason->new( -CatchErrors );

Use the execute method to parse and evalute a template:

    print $mason->execute( text=>$template, 'name'=>'Dave' );

Or compile it into a subroutine, and evaluate repeatedly:

    $coderef = $mason->compile( text=>$template );
    print $coderef->('name'=>'Dave');

Result is undef on exception, plus an error message if in list context:

    ($coderef, $error) = $mason->compile( text=>$template );
    ($result,  $error) = $mason->execute( text=>$template, 'name'=>'Dave' );


=head1 DESCRIPTION

This package adds exception catching to MicroMason, allowing you to check
an error variable rather than wrapping every call in an eval.

Both compilation and run-time errors in your template are handled as fatal
exceptions. The base MicroMason class will croak() if you attempt to
compile or execute a template which contains a incorrect fragment of Perl
syntax. Similarly, if the Perl code in your template causes die() or
croak() to be called, this will interupt your program unless caught by an
eval block.

This class provides that error catching behavior for the compile and
execute methods. It is implemented using the @MIXIN feature provided by
Text::MicroMason's class() method.

In a scalar context they return the result of the call, or undef if it
failed; in a list context they return the results of the call (undef if
it failed) followed by the error message (undef if it succeeded).

=head2 Public Methods

=over 4

=item compile()

  $code_ref = $mason->compile( text => $template, %options );
  ($coderef, $error) = $mason->compile( text=>$template, %options );

Uses an eval block to provide an exception catching wrapper for the compile method.

=item execute()

  $result = $mason->execute( text => $template, @arguments );
  ($result,  $error) = $mason->execute( text=>$template, 'name'=>'Dave' );

Uses an eval block to provide an exception catching wrapper for the execute method.

=back


=head1 SEE ALSO

For the core functionality of this package see L<Text::MicroMason> and L<Text::MicroMason::Base>.

For distribution, installation, support, copyright and license 
information, see L<Text::MicroMason::ReadMe>.

=cut

==> Text-MicroMason-1.93_0.tar.gz: Text-MicroMason-1.93/MicroMason/CatchErrors.pm <==
package Text::MicroMason::CatchErrors;

use strict;
use Carp;

######################################################################

use vars qw( %Defaults );

$Defaults{ error_string } = 1;

######################################################################

sub compile {
  my $result = eval { local $SIG{__DIE__}; (shift)->SUPER('compile', @_) };
  wantarray ? ($result, $@) : $result;
}

sub execute {
  my $result = eval { local $SIG{__DIE__}; (shift)->SUPER('execute', @_) };
  wantarray ? ($result, $@) : $result;
}

######################################################################

1;

__END__

######################################################################

=head1 NAME

Text::MicroMason::CatchErrors - Add Exception Catching for Templates


=head1 SYNOPSIS

Instead of using this class directly, pass its name to be mixed in:

    use Text::MicroMason;
    my $mason = Text::MicroMason->new( -CatchErrors );

Use the execute method to parse and evalute a template:

    print $mason->execute( text=>$template, 'name'=>'Dave' );

Or compile it into a subroutine, and evaluate repeatedly:

    $coderef = $mason->compile( text=>$template );
    print $coderef->('name'=>'Dave');

Result is undef on exception, plus an error message if in list context:

    ($coderef, $error) = $mason->compile( text=>$template );
    ($result,  $error) = $mason->execute( text=>$template, 'name'=>'Dave' );


=head1 DESCRIPTION

This package adds exception catching to MicroMason, allowing you to check
an error variable rather than wrapping every call in an eval.

Both compilation and run-time errors in your template are handled as fatal
exceptions. The base MicroMason class will croak() if you attempt to
compile or execute a template which contains a incorrect fragment of Perl
syntax. Similarly, if the Perl code in your template causes die() or
croak() to be called, this will interupt your program unless caught by an
eval block.

This class provides that error catching behavior for the compile and
execute methods.

In a scalar context they return the result of the call, or undef if it
failed; in a list context they return the results of the call (undef if
it failed) followed by the error message (undef if it succeeded).

=head2 Public Methods

=over 4

=item compile()

  $code_ref = $mason->compile( text => $template, %options );
  ($coderef, $error) = $mason->compile( text=>$template, %options );

Uses an eval block to provide an exception catching wrapper for the compile method.

=item execute()

  $result = $mason->execute( text => $template, @arguments );
  ($result,  $error) = $mason->execute( text=>$template, 'name'=>'Dave' );

Uses an eval block to provide an exception catching wrapper for the execute method.

=back


=head1 SEE ALSO

For the core functionality of this package see L<Text::MicroMason> and L<Text::MicroMason::Base>.

For distribution, installation, support, copyright and license 
information, see L<Text::MicroMason::ReadMe>.

=cut
